core.match_filter.tribe
---------------------------

.. currentmodule:: eqcorrscan.core.match_filter.tribe
.. automodule:: eqcorrscan.core.match_filter.tribe

----

.. comment to end block

.. autoclass:: Tribe

   .. rubric:: Methods

   .. autosummary::

      client_detect
      cluster
      construct
      copy
      detect
      read
      remove
      select
      sort
      write

   .. automethod:: __init__
   .. automethod:: client_detect
   .. automethod:: cluster
   .. automethod:: construct
   .. automethod:: copy
   .. automethod:: detect
   .. automethod:: read
   .. automethod:: remove
   .. automethod:: select
   .. automethod:: sort
   .. automethod:: write

Functions
----

.. autofunction:: read_tribe

.. comment to end block